/*******************************************************************************
* File Name: CURRENT_SENSOR_PM.c
* Version 2.10
*
* Description:
*  This file provides Sleep/WakeUp APIs functionality.
*
* Note:
*
********************************************************************************
* Copyright 2008-2013, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "CURRENT_SENSOR.h"


/***************************************
* Local data allocation
***************************************/

static CURRENT_SENSOR_BACKUP_STRUCT  CURRENT_SENSOR_backup =
{
    CURRENT_SENSOR_DISABLED
};


/*******************************************************************************
* Function Name: CURRENT_SENSOR_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the current user configuration.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void CURRENT_SENSOR_SaveConfig(void)
{
    /* All configuration registers are marked as [reset_all_retention] */
}


/*******************************************************************************
* Function Name: CURRENT_SENSOR_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void CURRENT_SENSOR_RestoreConfig(void)
{
    /* All congiguration registers are marked as [reset_all_retention] */
}


/*******************************************************************************
* Function Name: CURRENT_SENSOR_Sleep
********************************************************************************
*
* Summary:
*  This is the preferred routine to prepare the component for sleep.
*  The CURRENT_SENSOR_Sleep() routine saves the current component state,
*  then it calls the ADC_Stop() function.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  CURRENT_SENSOR_backup - modified.
*
*******************************************************************************/
void CURRENT_SENSOR_Sleep(void)
{
    if((CURRENT_SENSOR_PWRMGR_SAR_REG  & CURRENT_SENSOR_ACT_PWR_SAR_EN) != 0u)
    {
        if((CURRENT_SENSOR_SAR_CSR0_REG & CURRENT_SENSOR_SAR_SOF_START_CONV) != 0u)
        {
            CURRENT_SENSOR_backup.enableState = CURRENT_SENSOR_ENABLED | CURRENT_SENSOR_STARTED;
        }
        else
        {
            CURRENT_SENSOR_backup.enableState = CURRENT_SENSOR_ENABLED;
        }
        CURRENT_SENSOR_Stop();
    }
    else
    {
        CURRENT_SENSOR_backup.enableState = CURRENT_SENSOR_DISABLED;
    }
}


/*******************************************************************************
* Function Name: CURRENT_SENSOR_Wakeup
********************************************************************************
*
* Summary:
*  This is the preferred routine to restore the component to the state when
*  CURRENT_SENSOR_Sleep() was called. If the component was enabled before the
*  CURRENT_SENSOR_Sleep() function was called, the
*  CURRENT_SENSOR_Wakeup() function also re-enables the component.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  CURRENT_SENSOR_backup - used to check enabable state.
*
*******************************************************************************/
void CURRENT_SENSOR_Wakeup(void)
{
    if(CURRENT_SENSOR_backup.enableState != CURRENT_SENSOR_DISABLED)
    {
        CURRENT_SENSOR_Enable();
        #if(CURRENT_SENSOR_DEFAULT_CONV_MODE != CURRENT_SENSOR__HARDWARE_TRIGGER)
            if((CURRENT_SENSOR_backup.enableState & CURRENT_SENSOR_STARTED) != 0u)
            {
                CURRENT_SENSOR_StartConvert();
            }
        #endif /* End CURRENT_SENSOR_DEFAULT_CONV_MODE != CURRENT_SENSOR__HARDWARE_TRIGGER */
    }
}


/* [] END OF FILE */
