/*******************************************************************************
* File Name: IMINUS.c  
* Version 2.0
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "IMINUS.h"

/* APIs are not generated for P15[7:6] on PSoC 5 */
#if !(CY_PSOC5A &&\
	 IMINUS__PORT == 15 && ((IMINUS__MASK & 0xC0) != 0))


/*******************************************************************************
* Function Name: IMINUS_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None
*  
*******************************************************************************/
void IMINUS_Write(uint8 value) 
{
    uint8 staticBits = (IMINUS_DR & (uint8)(~IMINUS_MASK));
    IMINUS_DR = staticBits | ((uint8)(value << IMINUS_SHIFT) & IMINUS_MASK);
}


/*******************************************************************************
* Function Name: IMINUS_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  IMINUS_DM_STRONG     Strong Drive 
*  IMINUS_DM_OD_HI      Open Drain, Drives High 
*  IMINUS_DM_OD_LO      Open Drain, Drives Low 
*  IMINUS_DM_RES_UP     Resistive Pull Up 
*  IMINUS_DM_RES_DWN    Resistive Pull Down 
*  IMINUS_DM_RES_UPDWN  Resistive Pull Up/Down 
*  IMINUS_DM_DIG_HIZ    High Impedance Digital 
*  IMINUS_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void IMINUS_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(IMINUS_0, mode);
}


/*******************************************************************************
* Function Name: IMINUS_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro IMINUS_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 IMINUS_Read(void) 
{
    return (IMINUS_PS & IMINUS_MASK) >> IMINUS_SHIFT;
}


/*******************************************************************************
* Function Name: IMINUS_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 IMINUS_ReadDataReg(void) 
{
    return (IMINUS_DR & IMINUS_MASK) >> IMINUS_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(IMINUS_INTSTAT) 

    /*******************************************************************************
    * Function Name: IMINUS_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 IMINUS_ClearInterrupt(void) 
    {
        return (IMINUS_INTSTAT & IMINUS_MASK) >> IMINUS_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif /* CY_PSOC5A... */

    
/* [] END OF FILE */
