/*******************************************************************************
* File Name: IPLUS.c  
* Version 2.0
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "IPLUS.h"

/* APIs are not generated for P15[7:6] on PSoC 5 */
#if !(CY_PSOC5A &&\
	 IPLUS__PORT == 15 && ((IPLUS__MASK & 0xC0) != 0))


/*******************************************************************************
* Function Name: IPLUS_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None
*  
*******************************************************************************/
void IPLUS_Write(uint8 value) 
{
    uint8 staticBits = (IPLUS_DR & (uint8)(~IPLUS_MASK));
    IPLUS_DR = staticBits | ((uint8)(value << IPLUS_SHIFT) & IPLUS_MASK);
}


/*******************************************************************************
* Function Name: IPLUS_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  IPLUS_DM_STRONG     Strong Drive 
*  IPLUS_DM_OD_HI      Open Drain, Drives High 
*  IPLUS_DM_OD_LO      Open Drain, Drives Low 
*  IPLUS_DM_RES_UP     Resistive Pull Up 
*  IPLUS_DM_RES_DWN    Resistive Pull Down 
*  IPLUS_DM_RES_UPDWN  Resistive Pull Up/Down 
*  IPLUS_DM_DIG_HIZ    High Impedance Digital 
*  IPLUS_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void IPLUS_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(IPLUS_0, mode);
}


/*******************************************************************************
* Function Name: IPLUS_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro IPLUS_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 IPLUS_Read(void) 
{
    return (IPLUS_PS & IPLUS_MASK) >> IPLUS_SHIFT;
}


/*******************************************************************************
* Function Name: IPLUS_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 IPLUS_ReadDataReg(void) 
{
    return (IPLUS_DR & IPLUS_MASK) >> IPLUS_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(IPLUS_INTSTAT) 

    /*******************************************************************************
    * Function Name: IPLUS_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 IPLUS_ClearInterrupt(void) 
    {
        return (IPLUS_INTSTAT & IPLUS_MASK) >> IPLUS_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif /* CY_PSOC5A... */

    
/* [] END OF FILE */
