/*******************************************************************************
* File Name: USER_UART_1.h
* Version 2.30
*
* Description:
*  Contains the function prototypes and constants available to the UART
*  user module.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/


#if !defined(CY_UART_USER_UART_1_H)
#define CY_UART_USER_UART_1_H

#include "cytypes.h"
#include "cyfitter.h"
#include "CyLib.h"


/***************************************
* Conditional Compilation Parameters
***************************************/

#define USER_UART_1_RX_ENABLED                     (1u)
#define USER_UART_1_TX_ENABLED                     (1u)
#define USER_UART_1_HD_ENABLED                     (0u)
#define USER_UART_1_RX_INTERRUPT_ENABLED           (0u)
#define USER_UART_1_TX_INTERRUPT_ENABLED           (0u)
#define USER_UART_1_INTERNAL_CLOCK_USED            (1u)
#define USER_UART_1_RXHW_ADDRESS_ENABLED           (0u)
#define USER_UART_1_OVER_SAMPLE_COUNT              (16u)
#define USER_UART_1_PARITY_TYPE                    (0u)
#define USER_UART_1_PARITY_TYPE_SW                 (0u)
#define USER_UART_1_BREAK_DETECT                   (0u)
#define USER_UART_1_BREAK_BITS_TX                  (13u)
#define USER_UART_1_BREAK_BITS_RX                  (13u)
#define USER_UART_1_TXCLKGEN_DP                    (1u)
#define USER_UART_1_USE23POLLING                   (0u)
#define USER_UART_1_FLOW_CONTROL                   (0u)
#define USER_UART_1_CLK_FREQ                       (0u)
#define USER_UART_1_TXBUFFERSIZE                   (4u)
#define USER_UART_1_RXBUFFERSIZE                   (4u)

/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5LP)
    #error Component UART_v2_30 requires cy_boot v3.0 or later
#endif /* (CY_PSOC5LP) */

#ifdef USER_UART_1_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG
    #define USER_UART_1_CONTROL_REG_REMOVED            (0u)
#else
    #define USER_UART_1_CONTROL_REG_REMOVED            (1u)
#endif /* End USER_UART_1_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG */


/***************************************
*      Data Struct Definition
***************************************/

/* Sleep Mode API Support */
typedef struct USER_UART_1_backupStruct_
{
    uint8 enableState;

    #if(USER_UART_1_CONTROL_REG_REMOVED == 0u)
        uint8 cr;
    #endif /* End USER_UART_1_CONTROL_REG_REMOVED */
    #if( (USER_UART_1_RX_ENABLED) || (USER_UART_1_HD_ENABLED) )
        uint8 rx_period;
        #if (CY_UDB_V0)
            uint8 rx_mask;
            #if (USER_UART_1_RXHW_ADDRESS_ENABLED)
                uint8 rx_addr1;
                uint8 rx_addr2;
            #endif /* End USER_UART_1_RXHW_ADDRESS_ENABLED */
        #endif /* End CY_UDB_V0 */
    #endif  /* End (USER_UART_1_RX_ENABLED) || (USER_UART_1_HD_ENABLED)*/

    #if(USER_UART_1_TX_ENABLED)
        #if(USER_UART_1_TXCLKGEN_DP)
            uint8 tx_clk_ctr;
            #if (CY_UDB_V0)
                uint8 tx_clk_compl;
            #endif  /* End CY_UDB_V0 */
        #else
            uint8 tx_period;
        #endif /*End USER_UART_1_TXCLKGEN_DP */
        #if (CY_UDB_V0)
            uint8 tx_mask;
        #endif  /* End CY_UDB_V0 */
    #endif /*End USER_UART_1_TX_ENABLED */
} USER_UART_1_BACKUP_STRUCT;


/***************************************
*       Function Prototypes
***************************************/

void USER_UART_1_Start(void) ;
void USER_UART_1_Stop(void) ;
uint8 USER_UART_1_ReadControlRegister(void) ;
void USER_UART_1_WriteControlRegister(uint8 control) ;

void USER_UART_1_Init(void) ;
void USER_UART_1_Enable(void) ;
void USER_UART_1_SaveConfig(void) ;
void USER_UART_1_RestoreConfig(void) ;
void USER_UART_1_Sleep(void) ;
void USER_UART_1_Wakeup(void) ;

/* Only if RX is enabled */
#if( (USER_UART_1_RX_ENABLED) || (USER_UART_1_HD_ENABLED) )

    #if(USER_UART_1_RX_INTERRUPT_ENABLED)
        void  USER_UART_1_EnableRxInt(void) ;
        void  USER_UART_1_DisableRxInt(void) ;
        CY_ISR_PROTO(USER_UART_1_RXISR);
    #endif /* USER_UART_1_RX_INTERRUPT_ENABLED */

    void USER_UART_1_SetRxAddressMode(uint8 addressMode)
                                                           ;
    void USER_UART_1_SetRxAddress1(uint8 address) ;
    void USER_UART_1_SetRxAddress2(uint8 address) ;

    void  USER_UART_1_SetRxInterruptMode(uint8 intSrc) ;
    uint8 USER_UART_1_ReadRxData(void) ;
    uint8 USER_UART_1_ReadRxStatus(void) ;
    uint8 USER_UART_1_GetChar(void) ;
    uint16 USER_UART_1_GetByte(void) ;
    uint8 USER_UART_1_GetRxBufferSize(void)
                                                            ;
    void USER_UART_1_ClearRxBuffer(void) ;

    /* Obsolete functions, defines for backward compatible */
    #define USER_UART_1_GetRxInterruptSource   USER_UART_1_ReadRxStatus

#endif /* End (USER_UART_1_RX_ENABLED) || (USER_UART_1_HD_ENABLED) */

/* Only if TX is enabled */
#if(USER_UART_1_TX_ENABLED || USER_UART_1_HD_ENABLED)

    #if(USER_UART_1_TX_INTERRUPT_ENABLED)
        void USER_UART_1_EnableTxInt(void) ;
        void USER_UART_1_DisableTxInt(void) ;
        CY_ISR_PROTO(USER_UART_1_TXISR);
    #endif /* USER_UART_1_TX_INTERRUPT_ENABLED */

    void USER_UART_1_SetTxInterruptMode(uint8 intSrc) ;
    void USER_UART_1_WriteTxData(uint8 txDataByte) ;
    uint8 USER_UART_1_ReadTxStatus(void) ;
    void USER_UART_1_PutChar(uint8 txDataByte) ;
    void USER_UART_1_PutString(const char8 string[]) ;
    void USER_UART_1_PutArray(const uint8 string[], uint8 byteCount)
                                                            ;
    void USER_UART_1_PutCRLF(uint8 txDataByte) ;
    void USER_UART_1_ClearTxBuffer(void) ;
    void USER_UART_1_SetTxAddressMode(uint8 addressMode) ;
    void USER_UART_1_SendBreak(uint8 retMode) ;
    uint8 USER_UART_1_GetTxBufferSize(void)
                                                            ;
    /* Obsolete functions, defines for backward compatible */
    #define USER_UART_1_PutStringConst         USER_UART_1_PutString
    #define USER_UART_1_PutArrayConst          USER_UART_1_PutArray
    #define USER_UART_1_GetTxInterruptSource   USER_UART_1_ReadTxStatus

#endif /* End USER_UART_1_TX_ENABLED || USER_UART_1_HD_ENABLED */

#if(USER_UART_1_HD_ENABLED)
    void USER_UART_1_LoadRxConfig(void) ;
    void USER_UART_1_LoadTxConfig(void) ;
#endif /* End USER_UART_1_HD_ENABLED */


/* Communication bootloader APIs */
#if defined(CYDEV_BOOTLOADER_IO_COMP) && ((CYDEV_BOOTLOADER_IO_COMP == CyBtldr_USER_UART_1) || \
                                          (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_Custom_Interface))
    /* Physical layer functions */
    void    USER_UART_1_CyBtldrCommStart(void) CYSMALL ;
    void    USER_UART_1_CyBtldrCommStop(void) CYSMALL ;
    void    USER_UART_1_CyBtldrCommReset(void) CYSMALL ;
    cystatus USER_UART_1_CyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut) CYSMALL
             ;
    cystatus USER_UART_1_CyBtldrCommRead(uint8 pData[], uint16 size, uint16 * count, uint8 timeOut) CYSMALL
             ;

    #if (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_USER_UART_1)
        #define CyBtldrCommStart    USER_UART_1_CyBtldrCommStart
        #define CyBtldrCommStop     USER_UART_1_CyBtldrCommStop
        #define CyBtldrCommReset    USER_UART_1_CyBtldrCommReset
        #define CyBtldrCommWrite    USER_UART_1_CyBtldrCommWrite
        #define CyBtldrCommRead     USER_UART_1_CyBtldrCommRead
    #endif  /* (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_USER_UART_1) */

    /* Byte to Byte time out for detecting end of block data from host */
    #define USER_UART_1_BYTE2BYTE_TIME_OUT (25u)

#endif /* CYDEV_BOOTLOADER_IO_COMP */


/***************************************
*          API Constants
***************************************/
/* Parameters for SetTxAddressMode API*/
#define USER_UART_1_SET_SPACE                              (0x00u)
#define USER_UART_1_SET_MARK                               (0x01u)

/* Status Register definitions */
#if( (USER_UART_1_TX_ENABLED) || (USER_UART_1_HD_ENABLED) )
    #if(USER_UART_1_TX_INTERRUPT_ENABLED)
        #define USER_UART_1_TX_VECT_NUM            (uint8)USER_UART_1_TXInternalInterrupt__INTC_NUMBER
        #define USER_UART_1_TX_PRIOR_NUM           (uint8)USER_UART_1_TXInternalInterrupt__INTC_PRIOR_NUM
    #endif /* USER_UART_1_TX_INTERRUPT_ENABLED */
    #if(USER_UART_1_TX_ENABLED)
        #define USER_UART_1_TX_STS_COMPLETE_SHIFT          (0x00u)
        #define USER_UART_1_TX_STS_FIFO_EMPTY_SHIFT        (0x01u)
        #define USER_UART_1_TX_STS_FIFO_FULL_SHIFT         (0x02u)
        #define USER_UART_1_TX_STS_FIFO_NOT_FULL_SHIFT     (0x03u)
    #endif /* USER_UART_1_TX_ENABLED */
    #if(USER_UART_1_HD_ENABLED)
        #define USER_UART_1_TX_STS_COMPLETE_SHIFT          (0x00u)
        #define USER_UART_1_TX_STS_FIFO_EMPTY_SHIFT        (0x01u)
        #define USER_UART_1_TX_STS_FIFO_FULL_SHIFT         (0x05u)  /*needs MD=0*/
        #define USER_UART_1_TX_STS_FIFO_NOT_FULL_SHIFT     (0x03u)
    #endif /* USER_UART_1_HD_ENABLED */
    #define USER_UART_1_TX_STS_COMPLETE            (uint8)(0x01u << USER_UART_1_TX_STS_COMPLETE_SHIFT)
    #define USER_UART_1_TX_STS_FIFO_EMPTY          (uint8)(0x01u << USER_UART_1_TX_STS_FIFO_EMPTY_SHIFT)
    #define USER_UART_1_TX_STS_FIFO_FULL           (uint8)(0x01u << USER_UART_1_TX_STS_FIFO_FULL_SHIFT)
    #define USER_UART_1_TX_STS_FIFO_NOT_FULL       (uint8)(0x01u << USER_UART_1_TX_STS_FIFO_NOT_FULL_SHIFT)
#endif /* End (USER_UART_1_TX_ENABLED) || (USER_UART_1_HD_ENABLED)*/

#if( (USER_UART_1_RX_ENABLED) || (USER_UART_1_HD_ENABLED) )
    #if(USER_UART_1_RX_INTERRUPT_ENABLED)
        #define USER_UART_1_RX_VECT_NUM            (uint8)USER_UART_1_RXInternalInterrupt__INTC_NUMBER
        #define USER_UART_1_RX_PRIOR_NUM           (uint8)USER_UART_1_RXInternalInterrupt__INTC_PRIOR_NUM
    #endif /* USER_UART_1_RX_INTERRUPT_ENABLED */
    #define USER_UART_1_RX_STS_MRKSPC_SHIFT            (0x00u)
    #define USER_UART_1_RX_STS_BREAK_SHIFT             (0x01u)
    #define USER_UART_1_RX_STS_PAR_ERROR_SHIFT         (0x02u)
    #define USER_UART_1_RX_STS_STOP_ERROR_SHIFT        (0x03u)
    #define USER_UART_1_RX_STS_OVERRUN_SHIFT           (0x04u)
    #define USER_UART_1_RX_STS_FIFO_NOTEMPTY_SHIFT     (0x05u)
    #define USER_UART_1_RX_STS_ADDR_MATCH_SHIFT        (0x06u)
    #define USER_UART_1_RX_STS_SOFT_BUFF_OVER_SHIFT    (0x07u)

    #define USER_UART_1_RX_STS_MRKSPC           (uint8)(0x01u << USER_UART_1_RX_STS_MRKSPC_SHIFT)
    #define USER_UART_1_RX_STS_BREAK            (uint8)(0x01u << USER_UART_1_RX_STS_BREAK_SHIFT)
    #define USER_UART_1_RX_STS_PAR_ERROR        (uint8)(0x01u << USER_UART_1_RX_STS_PAR_ERROR_SHIFT)
    #define USER_UART_1_RX_STS_STOP_ERROR       (uint8)(0x01u << USER_UART_1_RX_STS_STOP_ERROR_SHIFT)
    #define USER_UART_1_RX_STS_OVERRUN          (uint8)(0x01u << USER_UART_1_RX_STS_OVERRUN_SHIFT)
    #define USER_UART_1_RX_STS_FIFO_NOTEMPTY    (uint8)(0x01u << USER_UART_1_RX_STS_FIFO_NOTEMPTY_SHIFT)
    #define USER_UART_1_RX_STS_ADDR_MATCH       (uint8)(0x01u << USER_UART_1_RX_STS_ADDR_MATCH_SHIFT)
    #define USER_UART_1_RX_STS_SOFT_BUFF_OVER   (uint8)(0x01u << USER_UART_1_RX_STS_SOFT_BUFF_OVER_SHIFT)
    #define USER_UART_1_RX_HW_MASK                     (0x7Fu)
#endif /* End (USER_UART_1_RX_ENABLED) || (USER_UART_1_HD_ENABLED) */

/* Control Register definitions */
#define USER_UART_1_CTRL_HD_SEND_SHIFT                 (0x00u) /* 1 enable TX part in Half Duplex mode */
#define USER_UART_1_CTRL_HD_SEND_BREAK_SHIFT           (0x01u) /* 1 send BREAK signal in Half Duplez mode */
#define USER_UART_1_CTRL_MARK_SHIFT                    (0x02u) /* 1 sets mark, 0 sets space */
#define USER_UART_1_CTRL_PARITY_TYPE0_SHIFT            (0x03u) /* Defines the type of parity implemented */
#define USER_UART_1_CTRL_PARITY_TYPE1_SHIFT            (0x04u) /* Defines the type of parity implemented */
#define USER_UART_1_CTRL_RXADDR_MODE0_SHIFT            (0x05u)
#define USER_UART_1_CTRL_RXADDR_MODE1_SHIFT            (0x06u)
#define USER_UART_1_CTRL_RXADDR_MODE2_SHIFT            (0x07u)

#define USER_UART_1_CTRL_HD_SEND               (uint8)(0x01u << USER_UART_1_CTRL_HD_SEND_SHIFT)
#define USER_UART_1_CTRL_HD_SEND_BREAK         (uint8)(0x01u << USER_UART_1_CTRL_HD_SEND_BREAK_SHIFT)
#define USER_UART_1_CTRL_MARK                  (uint8)(0x01u << USER_UART_1_CTRL_MARK_SHIFT)
#define USER_UART_1_CTRL_PARITY_TYPE_MASK      (uint8)(0x03u << USER_UART_1_CTRL_PARITY_TYPE0_SHIFT)
#define USER_UART_1_CTRL_RXADDR_MODE_MASK      (uint8)(0x07u << USER_UART_1_CTRL_RXADDR_MODE0_SHIFT)

/* StatusI Register Interrupt Enable Control Bits. As defined by the Register map for the AUX Control Register */
#define USER_UART_1_INT_ENABLE                         (0x10u)

/* Bit Counter (7-bit) Control Register Bit Definitions. As defined by the Register map for the AUX Control Register */
#define USER_UART_1_CNTR_ENABLE                        (0x20u)

/*   Constants for SendBreak() "retMode" parameter  */
#define USER_UART_1_SEND_BREAK                         (0x00u)
#define USER_UART_1_WAIT_FOR_COMPLETE_REINIT           (0x01u)
#define USER_UART_1_REINIT                             (0x02u)
#define USER_UART_1_SEND_WAIT_REINIT                   (0x03u)

#define USER_UART_1_OVER_SAMPLE_8                      (8u)
#define USER_UART_1_OVER_SAMPLE_16                     (16u)

#define USER_UART_1_BIT_CENTER                         (USER_UART_1_OVER_SAMPLE_COUNT - 1u)

#define USER_UART_1_FIFO_LENGTH                        (4u)
#define USER_UART_1_NUMBER_OF_START_BIT                (1u)
#define USER_UART_1_MAX_BYTE_VALUE                     (0xFFu)

/* 8X always for count7 implementation*/
#define USER_UART_1_TXBITCTR_BREAKBITS8X   ((USER_UART_1_BREAK_BITS_TX * USER_UART_1_OVER_SAMPLE_8) - 1u)
/* 8X or 16X for DP implementation*/
#define USER_UART_1_TXBITCTR_BREAKBITS ((USER_UART_1_BREAK_BITS_TX * USER_UART_1_OVER_SAMPLE_COUNT) - 1u)

#define USER_UART_1_HALF_BIT_COUNT   \
                            (((USER_UART_1_OVER_SAMPLE_COUNT / 2u) + (USER_UART_1_USE23POLLING * 1u)) - 2u)
#if (USER_UART_1_OVER_SAMPLE_COUNT == USER_UART_1_OVER_SAMPLE_8)
    #define USER_UART_1_HD_TXBITCTR_INIT   (((USER_UART_1_BREAK_BITS_TX + \
                            USER_UART_1_NUMBER_OF_START_BIT) * USER_UART_1_OVER_SAMPLE_COUNT) - 1u)

    /* This parameter is increased on the 2 in 2 out of 3 mode to sample voting in the middle */
    #define USER_UART_1_RXBITCTR_INIT  ((((USER_UART_1_BREAK_BITS_RX + USER_UART_1_NUMBER_OF_START_BIT) \
                            * USER_UART_1_OVER_SAMPLE_COUNT) + USER_UART_1_HALF_BIT_COUNT) - 1u)


#else /* USER_UART_1_OVER_SAMPLE_COUNT == USER_UART_1_OVER_SAMPLE_16 */
    #define USER_UART_1_HD_TXBITCTR_INIT   ((8u * USER_UART_1_OVER_SAMPLE_COUNT) - 1u)
    /* 7bit counter need one more bit for OverSampleCount=16 */
    #define USER_UART_1_RXBITCTR_INIT      (((7u * USER_UART_1_OVER_SAMPLE_COUNT) - 1u) + \
                                                      USER_UART_1_HALF_BIT_COUNT)
#endif /* End USER_UART_1_OVER_SAMPLE_COUNT */
#define USER_UART_1_HD_RXBITCTR_INIT                   USER_UART_1_RXBITCTR_INIT


/***************************************
* Global variables external identifier
***************************************/

extern uint8 USER_UART_1_initVar;
#if( USER_UART_1_TX_ENABLED && (USER_UART_1_TXBUFFERSIZE > USER_UART_1_FIFO_LENGTH))
    extern volatile uint8 USER_UART_1_txBuffer[USER_UART_1_TXBUFFERSIZE];
    extern volatile uint8 USER_UART_1_txBufferRead;
    extern uint8 USER_UART_1_txBufferWrite;
#endif /* End USER_UART_1_TX_ENABLED */
#if( ( USER_UART_1_RX_ENABLED || USER_UART_1_HD_ENABLED ) && \
     (USER_UART_1_RXBUFFERSIZE > USER_UART_1_FIFO_LENGTH) )
    extern volatile uint8 USER_UART_1_rxBuffer[USER_UART_1_RXBUFFERSIZE];
    extern volatile uint8 USER_UART_1_rxBufferRead;
    extern volatile uint8 USER_UART_1_rxBufferWrite;
    extern volatile uint8 USER_UART_1_rxBufferLoopDetect;
    extern volatile uint8 USER_UART_1_rxBufferOverflow;
    #if (USER_UART_1_RXHW_ADDRESS_ENABLED)
        extern volatile uint8 USER_UART_1_rxAddressMode;
        extern volatile uint8 USER_UART_1_rxAddressDetected;
    #endif /* End EnableHWAddress */
#endif /* End USER_UART_1_RX_ENABLED */


/***************************************
* Enumerated Types and Parameters
***************************************/

#define USER_UART_1__B_UART__AM_SW_BYTE_BYTE 1
#define USER_UART_1__B_UART__AM_SW_DETECT_TO_BUFFER 2
#define USER_UART_1__B_UART__AM_HW_BYTE_BY_BYTE 3
#define USER_UART_1__B_UART__AM_HW_DETECT_TO_BUFFER 4
#define USER_UART_1__B_UART__AM_NONE 0

#define USER_UART_1__B_UART__NONE_REVB 0
#define USER_UART_1__B_UART__EVEN_REVB 1
#define USER_UART_1__B_UART__ODD_REVB 2
#define USER_UART_1__B_UART__MARK_SPACE_REVB 3



/***************************************
*    Initial Parameter Constants
***************************************/

/* UART shifts max 8 bits, Mark/Space functionality working if 9 selected */
#define USER_UART_1_NUMBER_OF_DATA_BITS    ((8u > 8u) ? 8u : 8u)
#define USER_UART_1_NUMBER_OF_STOP_BITS    (1u)

#if (USER_UART_1_RXHW_ADDRESS_ENABLED)
    #define USER_UART_1_RXADDRESSMODE      (0u)
    #define USER_UART_1_RXHWADDRESS1       (0u)
    #define USER_UART_1_RXHWADDRESS2       (0u)
    /* Backward compatible define */
    #define USER_UART_1_RXAddressMode      USER_UART_1_RXADDRESSMODE
#endif /* End EnableHWAddress */

#define USER_UART_1_INIT_RX_INTERRUPTS_MASK \
                                  (uint8)((0 << USER_UART_1_RX_STS_FIFO_NOTEMPTY_SHIFT) \
                                        | (0 << USER_UART_1_RX_STS_MRKSPC_SHIFT) \
                                        | (0 << USER_UART_1_RX_STS_ADDR_MATCH_SHIFT) \
                                        | (0 << USER_UART_1_RX_STS_PAR_ERROR_SHIFT) \
                                        | (0 << USER_UART_1_RX_STS_STOP_ERROR_SHIFT) \
                                        | (0 << USER_UART_1_RX_STS_BREAK_SHIFT) \
                                        | (0 << USER_UART_1_RX_STS_OVERRUN_SHIFT))

#define USER_UART_1_INIT_TX_INTERRUPTS_MASK \
                                  (uint8)((0 << USER_UART_1_TX_STS_COMPLETE_SHIFT) \
                                        | (0 << USER_UART_1_TX_STS_FIFO_EMPTY_SHIFT) \
                                        | (0 << USER_UART_1_TX_STS_FIFO_FULL_SHIFT) \
                                        | (0 << USER_UART_1_TX_STS_FIFO_NOT_FULL_SHIFT))


/***************************************
*              Registers
***************************************/

#ifdef USER_UART_1_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG
    #define USER_UART_1_CONTROL_REG \
                            (* (reg8 *) USER_UART_1_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG )
    #define USER_UART_1_CONTROL_PTR \
                            (  (reg8 *) USER_UART_1_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG )
#endif /* End USER_UART_1_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG */

#if(USER_UART_1_TX_ENABLED)
    #define USER_UART_1_TXDATA_REG          (* (reg8 *) USER_UART_1_BUART_sTX_TxShifter_u0__F0_REG)
    #define USER_UART_1_TXDATA_PTR          (  (reg8 *) USER_UART_1_BUART_sTX_TxShifter_u0__F0_REG)
    #define USER_UART_1_TXDATA_AUX_CTL_REG  (* (reg8 *) USER_UART_1_BUART_sTX_TxShifter_u0__DP_AUX_CTL_REG)
    #define USER_UART_1_TXDATA_AUX_CTL_PTR  (  (reg8 *) USER_UART_1_BUART_sTX_TxShifter_u0__DP_AUX_CTL_REG)
    #define USER_UART_1_TXSTATUS_REG        (* (reg8 *) USER_UART_1_BUART_sTX_TxSts__STATUS_REG)
    #define USER_UART_1_TXSTATUS_PTR        (  (reg8 *) USER_UART_1_BUART_sTX_TxSts__STATUS_REG)
    #define USER_UART_1_TXSTATUS_MASK_REG   (* (reg8 *) USER_UART_1_BUART_sTX_TxSts__MASK_REG)
    #define USER_UART_1_TXSTATUS_MASK_PTR   (  (reg8 *) USER_UART_1_BUART_sTX_TxSts__MASK_REG)
    #define USER_UART_1_TXSTATUS_ACTL_REG   (* (reg8 *) USER_UART_1_BUART_sTX_TxSts__STATUS_AUX_CTL_REG)
    #define USER_UART_1_TXSTATUS_ACTL_PTR   (  (reg8 *) USER_UART_1_BUART_sTX_TxSts__STATUS_AUX_CTL_REG)

    /* DP clock */
    #if(USER_UART_1_TXCLKGEN_DP)
        #define USER_UART_1_TXBITCLKGEN_CTR_REG        \
                                        (* (reg8 *) USER_UART_1_BUART_sTX_sCLOCK_TxBitClkGen__D0_REG)
        #define USER_UART_1_TXBITCLKGEN_CTR_PTR        \
                                        (  (reg8 *) USER_UART_1_BUART_sTX_sCLOCK_TxBitClkGen__D0_REG)
        #define USER_UART_1_TXBITCLKTX_COMPLETE_REG    \
                                        (* (reg8 *) USER_UART_1_BUART_sTX_sCLOCK_TxBitClkGen__D1_REG)
        #define USER_UART_1_TXBITCLKTX_COMPLETE_PTR    \
                                        (  (reg8 *) USER_UART_1_BUART_sTX_sCLOCK_TxBitClkGen__D1_REG)
    #else     /* Count7 clock*/
        #define USER_UART_1_TXBITCTR_PERIOD_REG    \
                                        (* (reg8 *) USER_UART_1_BUART_sTX_sCLOCK_TxBitCounter__PERIOD_REG)
        #define USER_UART_1_TXBITCTR_PERIOD_PTR    \
                                        (  (reg8 *) USER_UART_1_BUART_sTX_sCLOCK_TxBitCounter__PERIOD_REG)
        #define USER_UART_1_TXBITCTR_CONTROL_REG   \
                                        (* (reg8 *) USER_UART_1_BUART_sTX_sCLOCK_TxBitCounter__CONTROL_AUX_CTL_REG)
        #define USER_UART_1_TXBITCTR_CONTROL_PTR   \
                                        (  (reg8 *) USER_UART_1_BUART_sTX_sCLOCK_TxBitCounter__CONTROL_AUX_CTL_REG)
        #define USER_UART_1_TXBITCTR_COUNTER_REG   \
                                        (* (reg8 *) USER_UART_1_BUART_sTX_sCLOCK_TxBitCounter__COUNT_REG)
        #define USER_UART_1_TXBITCTR_COUNTER_PTR   \
                                        (  (reg8 *) USER_UART_1_BUART_sTX_sCLOCK_TxBitCounter__COUNT_REG)
    #endif /* USER_UART_1_TXCLKGEN_DP */

#endif /* End USER_UART_1_TX_ENABLED */

#if(USER_UART_1_HD_ENABLED)

    #define USER_UART_1_TXDATA_REG             (* (reg8 *) USER_UART_1_BUART_sRX_RxShifter_u0__F1_REG )
    #define USER_UART_1_TXDATA_PTR             (  (reg8 *) USER_UART_1_BUART_sRX_RxShifter_u0__F1_REG )
    #define USER_UART_1_TXDATA_AUX_CTL_REG     (* (reg8 *) USER_UART_1_BUART_sRX_RxShifter_u0__DP_AUX_CTL_REG)
    #define USER_UART_1_TXDATA_AUX_CTL_PTR     (  (reg8 *) USER_UART_1_BUART_sRX_RxShifter_u0__DP_AUX_CTL_REG)

    #define USER_UART_1_TXSTATUS_REG           (* (reg8 *) USER_UART_1_BUART_sRX_RxSts__STATUS_REG )
    #define USER_UART_1_TXSTATUS_PTR           (  (reg8 *) USER_UART_1_BUART_sRX_RxSts__STATUS_REG )
    #define USER_UART_1_TXSTATUS_MASK_REG      (* (reg8 *) USER_UART_1_BUART_sRX_RxSts__MASK_REG )
    #define USER_UART_1_TXSTATUS_MASK_PTR      (  (reg8 *) USER_UART_1_BUART_sRX_RxSts__MASK_REG )
    #define USER_UART_1_TXSTATUS_ACTL_REG      (* (reg8 *) USER_UART_1_BUART_sRX_RxSts__STATUS_AUX_CTL_REG )
    #define USER_UART_1_TXSTATUS_ACTL_PTR      (  (reg8 *) USER_UART_1_BUART_sRX_RxSts__STATUS_AUX_CTL_REG )
#endif /* End USER_UART_1_HD_ENABLED */

#if( (USER_UART_1_RX_ENABLED) || (USER_UART_1_HD_ENABLED) )
    #define USER_UART_1_RXDATA_REG             (* (reg8 *) USER_UART_1_BUART_sRX_RxShifter_u0__F0_REG )
    #define USER_UART_1_RXDATA_PTR             (  (reg8 *) USER_UART_1_BUART_sRX_RxShifter_u0__F0_REG )
    #define USER_UART_1_RXADDRESS1_REG         (* (reg8 *) USER_UART_1_BUART_sRX_RxShifter_u0__D0_REG )
    #define USER_UART_1_RXADDRESS1_PTR         (  (reg8 *) USER_UART_1_BUART_sRX_RxShifter_u0__D0_REG )
    #define USER_UART_1_RXADDRESS2_REG         (* (reg8 *) USER_UART_1_BUART_sRX_RxShifter_u0__D1_REG )
    #define USER_UART_1_RXADDRESS2_PTR         (  (reg8 *) USER_UART_1_BUART_sRX_RxShifter_u0__D1_REG )
    #define USER_UART_1_RXDATA_AUX_CTL_REG     (* (reg8 *) USER_UART_1_BUART_sRX_RxShifter_u0__DP_AUX_CTL_REG)

    #define USER_UART_1_RXBITCTR_PERIOD_REG    (* (reg8 *) USER_UART_1_BUART_sRX_RxBitCounter__PERIOD_REG )
    #define USER_UART_1_RXBITCTR_PERIOD_PTR    (  (reg8 *) USER_UART_1_BUART_sRX_RxBitCounter__PERIOD_REG )
    #define USER_UART_1_RXBITCTR_CONTROL_REG   \
                                        (* (reg8 *) USER_UART_1_BUART_sRX_RxBitCounter__CONTROL_AUX_CTL_REG )
    #define USER_UART_1_RXBITCTR_CONTROL_PTR   \
                                        (  (reg8 *) USER_UART_1_BUART_sRX_RxBitCounter__CONTROL_AUX_CTL_REG )
    #define USER_UART_1_RXBITCTR_COUNTER_REG   (* (reg8 *) USER_UART_1_BUART_sRX_RxBitCounter__COUNT_REG )
    #define USER_UART_1_RXBITCTR_COUNTER_PTR   (  (reg8 *) USER_UART_1_BUART_sRX_RxBitCounter__COUNT_REG )

    #define USER_UART_1_RXSTATUS_REG           (* (reg8 *) USER_UART_1_BUART_sRX_RxSts__STATUS_REG )
    #define USER_UART_1_RXSTATUS_PTR           (  (reg8 *) USER_UART_1_BUART_sRX_RxSts__STATUS_REG )
    #define USER_UART_1_RXSTATUS_MASK_REG      (* (reg8 *) USER_UART_1_BUART_sRX_RxSts__MASK_REG )
    #define USER_UART_1_RXSTATUS_MASK_PTR      (  (reg8 *) USER_UART_1_BUART_sRX_RxSts__MASK_REG )
    #define USER_UART_1_RXSTATUS_ACTL_REG      (* (reg8 *) USER_UART_1_BUART_sRX_RxSts__STATUS_AUX_CTL_REG )
    #define USER_UART_1_RXSTATUS_ACTL_PTR      (  (reg8 *) USER_UART_1_BUART_sRX_RxSts__STATUS_AUX_CTL_REG )
#endif /* End  (USER_UART_1_RX_ENABLED) || (USER_UART_1_HD_ENABLED) */

#if(USER_UART_1_INTERNAL_CLOCK_USED)
    /* Register to enable or disable the digital clocks */
    #define USER_UART_1_INTCLOCK_CLKEN_REG     (* (reg8 *) USER_UART_1_IntClock__PM_ACT_CFG)
    #define USER_UART_1_INTCLOCK_CLKEN_PTR     (  (reg8 *) USER_UART_1_IntClock__PM_ACT_CFG)

    /* Clock mask for this clock. */
    #define USER_UART_1_INTCLOCK_CLKEN_MASK    USER_UART_1_IntClock__PM_ACT_MSK
#endif /* End USER_UART_1_INTERNAL_CLOCK_USED */


/***************************************
*       Register Constants
***************************************/

#if(USER_UART_1_TX_ENABLED)
    #define USER_UART_1_TX_FIFO_CLR            (0x01u) /* FIFO0 CLR */
#endif /* End USER_UART_1_TX_ENABLED */

#if(USER_UART_1_HD_ENABLED)
    #define USER_UART_1_TX_FIFO_CLR            (0x02u) /* FIFO1 CLR */
#endif /* End USER_UART_1_HD_ENABLED */

#if( (USER_UART_1_RX_ENABLED) || (USER_UART_1_HD_ENABLED) )
    #define USER_UART_1_RX_FIFO_CLR            (0x01u) /* FIFO0 CLR */
#endif /* End  (USER_UART_1_RX_ENABLED) || (USER_UART_1_HD_ENABLED) */


/***************************************
* Renamed global variables or defines
* for backward compatible
***************************************/

#define USER_UART_1_initvar                    USER_UART_1_initVar

#define USER_UART_1_RX_Enabled                 USER_UART_1_RX_ENABLED
#define USER_UART_1_TX_Enabled                 USER_UART_1_TX_ENABLED
#define USER_UART_1_HD_Enabled                 USER_UART_1_HD_ENABLED
#define USER_UART_1_RX_IntInterruptEnabled     USER_UART_1_RX_INTERRUPT_ENABLED
#define USER_UART_1_TX_IntInterruptEnabled     USER_UART_1_TX_INTERRUPT_ENABLED
#define USER_UART_1_InternalClockUsed          USER_UART_1_INTERNAL_CLOCK_USED
#define USER_UART_1_RXHW_Address_Enabled       USER_UART_1_RXHW_ADDRESS_ENABLED
#define USER_UART_1_OverSampleCount            USER_UART_1_OVER_SAMPLE_COUNT
#define USER_UART_1_ParityType                 USER_UART_1_PARITY_TYPE

#if( USER_UART_1_TX_ENABLED && (USER_UART_1_TXBUFFERSIZE > USER_UART_1_FIFO_LENGTH))
    #define USER_UART_1_TXBUFFER               USER_UART_1_txBuffer
    #define USER_UART_1_TXBUFFERREAD           USER_UART_1_txBufferRead
    #define USER_UART_1_TXBUFFERWRITE          USER_UART_1_txBufferWrite
#endif /* End USER_UART_1_TX_ENABLED */
#if( ( USER_UART_1_RX_ENABLED || USER_UART_1_HD_ENABLED ) && \
     (USER_UART_1_RXBUFFERSIZE > USER_UART_1_FIFO_LENGTH) )
    #define USER_UART_1_RXBUFFER               USER_UART_1_rxBuffer
    #define USER_UART_1_RXBUFFERREAD           USER_UART_1_rxBufferRead
    #define USER_UART_1_RXBUFFERWRITE          USER_UART_1_rxBufferWrite
    #define USER_UART_1_RXBUFFERLOOPDETECT     USER_UART_1_rxBufferLoopDetect
    #define USER_UART_1_RXBUFFER_OVERFLOW      USER_UART_1_rxBufferOverflow
#endif /* End USER_UART_1_RX_ENABLED */

#ifdef USER_UART_1_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG
    #define USER_UART_1_CONTROL                USER_UART_1_CONTROL_REG
#endif /* End USER_UART_1_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG */

#if(USER_UART_1_TX_ENABLED)
    #define USER_UART_1_TXDATA                 USER_UART_1_TXDATA_REG
    #define USER_UART_1_TXSTATUS               USER_UART_1_TXSTATUS_REG
    #define USER_UART_1_TXSTATUS_MASK          USER_UART_1_TXSTATUS_MASK_REG
    #define USER_UART_1_TXSTATUS_ACTL          USER_UART_1_TXSTATUS_ACTL_REG
    /* DP clock */
    #if(USER_UART_1_TXCLKGEN_DP)
        #define USER_UART_1_TXBITCLKGEN_CTR        USER_UART_1_TXBITCLKGEN_CTR_REG
        #define USER_UART_1_TXBITCLKTX_COMPLETE    USER_UART_1_TXBITCLKTX_COMPLETE_REG
    #else     /* Count7 clock*/
        #define USER_UART_1_TXBITCTR_PERIOD        USER_UART_1_TXBITCTR_PERIOD_REG
        #define USER_UART_1_TXBITCTR_CONTROL       USER_UART_1_TXBITCTR_CONTROL_REG
        #define USER_UART_1_TXBITCTR_COUNTER       USER_UART_1_TXBITCTR_COUNTER_REG
    #endif /* USER_UART_1_TXCLKGEN_DP */
#endif /* End USER_UART_1_TX_ENABLED */

#if(USER_UART_1_HD_ENABLED)
    #define USER_UART_1_TXDATA                 USER_UART_1_TXDATA_REG
    #define USER_UART_1_TXSTATUS               USER_UART_1_TXSTATUS_REG
    #define USER_UART_1_TXSTATUS_MASK          USER_UART_1_TXSTATUS_MASK_REG
    #define USER_UART_1_TXSTATUS_ACTL          USER_UART_1_TXSTATUS_ACTL_REG
#endif /* End USER_UART_1_HD_ENABLED */

#if( (USER_UART_1_RX_ENABLED) || (USER_UART_1_HD_ENABLED) )
    #define USER_UART_1_RXDATA                 USER_UART_1_RXDATA_REG
    #define USER_UART_1_RXADDRESS1             USER_UART_1_RXADDRESS1_REG
    #define USER_UART_1_RXADDRESS2             USER_UART_1_RXADDRESS2_REG
    #define USER_UART_1_RXBITCTR_PERIOD        USER_UART_1_RXBITCTR_PERIOD_REG
    #define USER_UART_1_RXBITCTR_CONTROL       USER_UART_1_RXBITCTR_CONTROL_REG
    #define USER_UART_1_RXBITCTR_COUNTER       USER_UART_1_RXBITCTR_COUNTER_REG
    #define USER_UART_1_RXSTATUS               USER_UART_1_RXSTATUS_REG
    #define USER_UART_1_RXSTATUS_MASK          USER_UART_1_RXSTATUS_MASK_REG
    #define USER_UART_1_RXSTATUS_ACTL          USER_UART_1_RXSTATUS_ACTL_REG
#endif /* End  (USER_UART_1_RX_ENABLED) || (USER_UART_1_HD_ENABLED) */

#if(USER_UART_1_INTERNAL_CLOCK_USED)
    #define USER_UART_1_INTCLOCK_CLKEN         USER_UART_1_INTCLOCK_CLKEN_REG
#endif /* End USER_UART_1_INTERNAL_CLOCK_USED */

#define USER_UART_1_WAIT_FOR_COMLETE_REINIT    USER_UART_1_WAIT_FOR_COMPLETE_REINIT

#endif  /* CY_UART_USER_UART_1_H */


/* [] END OF FILE */
