/*******************************************************************************
* File Name: VMINUS.c  
* Version 2.0
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "VMINUS.h"

/* APIs are not generated for P15[7:6] on PSoC 5 */
#if !(CY_PSOC5A &&\
	 VMINUS__PORT == 15 && ((VMINUS__MASK & 0xC0) != 0))


/*******************************************************************************
* Function Name: VMINUS_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None
*  
*******************************************************************************/
void VMINUS_Write(uint8 value) 
{
    uint8 staticBits = (VMINUS_DR & (uint8)(~VMINUS_MASK));
    VMINUS_DR = staticBits | ((uint8)(value << VMINUS_SHIFT) & VMINUS_MASK);
}


/*******************************************************************************
* Function Name: VMINUS_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  VMINUS_DM_STRONG     Strong Drive 
*  VMINUS_DM_OD_HI      Open Drain, Drives High 
*  VMINUS_DM_OD_LO      Open Drain, Drives Low 
*  VMINUS_DM_RES_UP     Resistive Pull Up 
*  VMINUS_DM_RES_DWN    Resistive Pull Down 
*  VMINUS_DM_RES_UPDWN  Resistive Pull Up/Down 
*  VMINUS_DM_DIG_HIZ    High Impedance Digital 
*  VMINUS_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void VMINUS_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(VMINUS_0, mode);
}


/*******************************************************************************
* Function Name: VMINUS_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro VMINUS_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 VMINUS_Read(void) 
{
    return (VMINUS_PS & VMINUS_MASK) >> VMINUS_SHIFT;
}


/*******************************************************************************
* Function Name: VMINUS_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 VMINUS_ReadDataReg(void) 
{
    return (VMINUS_DR & VMINUS_MASK) >> VMINUS_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(VMINUS_INTSTAT) 

    /*******************************************************************************
    * Function Name: VMINUS_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 VMINUS_ClearInterrupt(void) 
    {
        return (VMINUS_INTSTAT & VMINUS_MASK) >> VMINUS_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif /* CY_PSOC5A... */

    
/* [] END OF FILE */
