/*******************************************************************************
* File Name: VOLTAGE_SENSOR_PM.c
* Version 2.10
*
* Description:
*  This file provides Sleep/WakeUp APIs functionality.
*
* Note:
*
********************************************************************************
* Copyright 2008-2013, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "VOLTAGE_SENSOR.h"


/***************************************
* Local data allocation
***************************************/

static VOLTAGE_SENSOR_BACKUP_STRUCT  VOLTAGE_SENSOR_backup =
{
    VOLTAGE_SENSOR_DISABLED
};


/*******************************************************************************
* Function Name: VOLTAGE_SENSOR_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the current user configuration.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void VOLTAGE_SENSOR_SaveConfig(void)
{
    /* All configuration registers are marked as [reset_all_retention] */
}


/*******************************************************************************
* Function Name: VOLTAGE_SENSOR_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void VOLTAGE_SENSOR_RestoreConfig(void)
{
    /* All congiguration registers are marked as [reset_all_retention] */
}


/*******************************************************************************
* Function Name: VOLTAGE_SENSOR_Sleep
********************************************************************************
*
* Summary:
*  This is the preferred routine to prepare the component for sleep.
*  The VOLTAGE_SENSOR_Sleep() routine saves the current component state,
*  then it calls the ADC_Stop() function.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  VOLTAGE_SENSOR_backup - modified.
*
*******************************************************************************/
void VOLTAGE_SENSOR_Sleep(void)
{
    if((VOLTAGE_SENSOR_PWRMGR_SAR_REG  & VOLTAGE_SENSOR_ACT_PWR_SAR_EN) != 0u)
    {
        if((VOLTAGE_SENSOR_SAR_CSR0_REG & VOLTAGE_SENSOR_SAR_SOF_START_CONV) != 0u)
        {
            VOLTAGE_SENSOR_backup.enableState = VOLTAGE_SENSOR_ENABLED | VOLTAGE_SENSOR_STARTED;
        }
        else
        {
            VOLTAGE_SENSOR_backup.enableState = VOLTAGE_SENSOR_ENABLED;
        }
        VOLTAGE_SENSOR_Stop();
    }
    else
    {
        VOLTAGE_SENSOR_backup.enableState = VOLTAGE_SENSOR_DISABLED;
    }
}


/*******************************************************************************
* Function Name: VOLTAGE_SENSOR_Wakeup
********************************************************************************
*
* Summary:
*  This is the preferred routine to restore the component to the state when
*  VOLTAGE_SENSOR_Sleep() was called. If the component was enabled before the
*  VOLTAGE_SENSOR_Sleep() function was called, the
*  VOLTAGE_SENSOR_Wakeup() function also re-enables the component.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  VOLTAGE_SENSOR_backup - used to check enabable state.
*
*******************************************************************************/
void VOLTAGE_SENSOR_Wakeup(void)
{
    if(VOLTAGE_SENSOR_backup.enableState != VOLTAGE_SENSOR_DISABLED)
    {
        VOLTAGE_SENSOR_Enable();
        #if(VOLTAGE_SENSOR_DEFAULT_CONV_MODE != VOLTAGE_SENSOR__HARDWARE_TRIGGER)
            if((VOLTAGE_SENSOR_backup.enableState & VOLTAGE_SENSOR_STARTED) != 0u)
            {
                VOLTAGE_SENSOR_StartConvert();
            }
        #endif /* End VOLTAGE_SENSOR_DEFAULT_CONV_MODE != VOLTAGE_SENSOR__HARDWARE_TRIGGER */
    }
}


/* [] END OF FILE */
