#include <project.h>
#include <stdio.h>
#include <Global.h>
#include <DAC.h>
#include <COMMANDS.h>

// Definitions.
#define NO_OF_SAMPLES 1024

// Declarations for CURRENT_DMA.
#define CURRENT_DMA_BYTES_PER_BURST 2
#define CURRENT_DMA_REQUEST_PER_BURST 1
#define CURRENT_DMA_SRC_BASE (CYDEV_PERIPH_BASE)
#define CURRENT_DMA_DST_BASE (CYDEV_SRAM_BASE)

// Variable declarations for CURRENT_DMA.
uint8 CURRENT_DMA_Chan;
uint8 CURRENT_DMA_TD[1];

volatile uint8 current_data_flag = FALSE;

//Function prototypes.
CY_ISR_PROTO(DMAHandler);							

int main()
{
    uint8 CURRENT_DMA_Chan;
    uint8 CURRENT_DMA_TD[1];

    int i;
    int16 ISamples[NO_OF_SAMPLES];
    
    char termstring[32];
    
    // Current DMA Configuration.
    CURRENT_DMA_Chan = SENSOR_DMA_DmaInitialize(CURRENT_DMA_BYTES_PER_BURST, CURRENT_DMA_REQUEST_PER_BURST, HI16(CURRENT_DMA_SRC_BASE), HI16(CURRENT_DMA_DST_BASE));
    CURRENT_DMA_TD[0] = CyDmaTdAllocate();
    CyDmaTdSetConfiguration(CURRENT_DMA_TD[0], (2*NO_OF_SAMPLES), CURRENT_DMA_TD[0], SENSOR_DMA__TD_TERMOUT_EN | TD_INC_DST_ADR);
    CyDmaTdSetAddress(CURRENT_DMA_TD[0], LO16((uint32)SENSOR_READER_DEC_SAMP_PTR), LO16((uint32)ISamples));
    CyDmaChSetInitialTd(CURRENT_DMA_Chan, CURRENT_DMA_TD[0]);
    
    // Start perepherials.
    CyDmaChEnable(CURRENT_DMA_Chan, 1);
    I_FINISHED_StartEx(DMAHandler);
    SENSOR_READER_Start();
    PC_UART_Start();
    CyGlobalIntEnable;

    while (forever)									
    {   
		SENSOR_READER_StartConvert();
        
        //	Wait until DMA transfer competed.
		if (current_data_flag == TRUE)
        {
            //	Wait DMA samples to UART.
    		for (i = 0; i < NO_OF_SAMPLES; i+=2) 		
    		{
    		    sprintf(termstring, "%i\r\n", ISamples[i]);
    		    PC_UART_PutString(termstring);  
    		}
            current_data_flag = FALSE;
        }
    }
}

// Handler for DMA done interrupt.
CY_ISR(DMAHandler)									
{
	current_data_flag = TRUE;
	SENSOR_READER_StopConvert();					
}

/* [] END OF FILE */
